@@ -1,6 +1,6 @@
 package Padre::Plugin::LaTeX;
 BEGIN {
-  $Padre::Plugin::LaTeX::VERSION = '0.09';
+  $Padre::Plugin::LaTeX::VERSION = '0.10';
 }
 
 # ABSTRACT: LaTeX support for Padre
@@ -8,6 +8,8 @@ BEGIN {
 use warnings;
 use strict;
 
+use File::Spec::Functions qw{ catfile };
+
 use base 'Padre::Plugin';
 use Padre::Wx ();
 
@@ -16,13 +18,25 @@ sub plugin_name {
 }
 
 sub padre_interfaces {
-	'Padre::Plugin' => 0.65, 'Padre::Document' => 0.65,;
+	'Padre::Plugin' => 0.81, 'Padre::Document' => 0.81;
 }
 
 sub registered_documents {
 	'application/x-latex' => 'Padre::Document::LaTeX', 'application/x-bibtex' => 'Padre::Document::BibTeX',;
 }
 
+sub plugin_icon {
+	my $self = shift;
+
+	# find resource path
+	my $iconpath = catfile( $self->plugin_directory_share, 'icons', 'text-x-tex.png' );
+
+	# create and return icon
+	return Wx::Bitmap->new( $iconpath, Wx::wxBITMAP_TYPE_PNG );
+
+	# TODO: simplify
+}
+
 sub menu_plugins_simple {
 	my $self = shift;
 	return $self->plugin_name => [
@@ -106,7 +120,7 @@ sub run_bibtex {
 
 	# TODO autosave (or ask)
 
-	chdir $tex_dir;
+	chdir $tex_dir; # TODO does this have side effects?
 	my $output_text = `$bibtex $aux_file`;
 	$self->_output($output_text);
 
@@ -124,20 +138,35 @@ sub view_pdf {
 		return;
 	}
 
-	# TODO find PDF viewer from system settings
-	my $pdf_viewer = 'evince';
-
 	my $pdf_file = $doc->filename;
 	$pdf_file =~ s/\.tex$/.pdf/;
 
 	if ( !-f $pdf_file ) {
+		main->error( sprintf( Wx::gettext("Could not find file '%s'."), $pdf_file ) );
+	}
 
+	$self->launch_pdf_viewer($pdf_file);
+
+	return;
+}
+
+
+sub launch_pdf_viewer {
+	my $self     = shift;
+	my $pdf_file = shift;
+
+	# TODO find PDF viewer from system settings like Debian alternatives
+	# TODO get PDF viewer from configuration
+
+	require File::Which;
+	my @pdf_viewers = qw/evince okular xpdf gv acroread/;
+	my $pdf_viewer  = '';
+	foreach my $program (@pdf_viewers) {
+		last if defined( $pdf_viewer = File::Which::which($program) );
 	}
 
 	system "$pdf_viewer $pdf_file &";
 
-	# TODO check for errors
-
 	return;
 }
 
@@ -162,6 +191,8 @@ sub _output {
 	$main->show_output(1);
 	$main->output->clear;
 	$main->output->AppendText($text);
+
+	return;
 }
 
 
@@ -176,7 +207,7 @@ Padre::Plugin::LaTeX - LaTeX support for Padre
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -185,7 +216,7 @@ Environment.
 
 Syntax highlighting for LaTeX is supported by Padre out of the box.
 This plug-in adds some more features to deal with LaTeX files.
-If you also want syntax highlighting for BibTeX files, try the Kate
+If you also want syntax highlighting for BibTeX files, install the Kate
 plugin.
 
 =head1 AUTHORS
